# Detailed documentation
* [API](api.md)
* [Internal design details](internals.md)
* Bonus extra features, or "things I thought were missing from Scratch" - TODO
* Extensions - the possibilities are endless: UIs, videos, AI, networking